package org.ow2.easybeans.deployment.annotations.helper;

import java.util.List;

import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarArchiveMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarClassMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.LibrariesAnnotationMetadata;

/**
 * Complete existing metadata by libraries metadata.
 * @author Florent BENOIT
 */
public final class ExtraMetadataHelper {

    /**
     * Utility class.
     */
    private ExtraMetadataHelper() {
    }

    /**
     * Complete the given EJB metadata by the metadata found in the libraries.
     * @param ejbMetadata the medata to complete
     * @param libAnnotationMetadata the given data of the libraries.
     */
    public static void complete(final EjbJarArchiveMetadata ejbMetadata,
            final LibrariesAnnotationMetadata libAnnotationMetadata) {

        // Nothing to complete
        if (libAnnotationMetadata == null) {
            return;
        }

        // List ?
        List<EjbJarArchiveMetadata> extraMetaDataList = libAnnotationMetadata.getEjbJarAnnotationMetadataList();

        // Nothing to do
        if (extraMetaDataList == null) {
            return;
        }

        for (EjbJarArchiveMetadata extraEjbJarAnnotationMetadata : extraMetaDataList) {
            for (EjbJarClassMetadata classAnnotationMetadata : extraEjbJarAnnotationMetadata
                    .getEjbJarClassMetadataCollection()) {
                // Data exist for the EJB ?
                EjbJarClassMetadata foundClassAnnotationMetadata = ejbMetadata
                        .getEjbJarClassMetadata(classAnnotationMetadata.getClassName());

                // Found something, continue
                if (foundClassAnnotationMetadata != null) {
                    continue;
                }

                // Not found, then complete
                ejbMetadata.addEjbJarClassMetadata(classAnnotationMetadata);

            }
        }
    }

}
