/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MethodPermission.java 2059 2007-11-22 17:22:33Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.easybeans.deployment.xml.struct.common.MethodDD;

/**
 * Defines a method permission used within an assembly descriptor.
 * @author Florent BENOIT
 */
public class MethodPermission {

    /**
     * Name of this element.
     */
    public static final String NAME = "method-permission";

    /**
     * List of methods on which apply this method permission block.
     */
    private List<MethodDD> methods = null;

    /**
     * Unchecked method block ?
     */
    private boolean unchecked = false;

    /**
     * Name of the roles.
     */
    private List<String> roleNameList = null;

    /**
     * Default constructor.
     */
    public MethodPermission() {
        this.roleNameList = new ArrayList<String>();
        this.methods = new ArrayList<MethodDD>();
    }


    /**
     * Sets the unchecked flag.
     * @param unchecked the given boolean value.
     */
    public void setUnchecked(final boolean unchecked) {
        this.unchecked = unchecked;
    }

    /**
     * Is it unchecked ?.
     * @return true if it is unchecked, else false.
     */
    public boolean isUnchecked() {
        return this.unchecked;
    }

    /**
     * Add a new Method.
     * @param method the given method.
     */
    public void addMethod(final MethodDD method) {
        this.methods.add(method);
    }

    /**
     * @return list of methods.
     */
    public List<MethodDD> getMethods() {
        return this.methods;
    }

    /**
     * Gets the name of the role.
     * @return the role's name.
     */
    public List<String> getRoleNameList() {
        return this.roleNameList;
    }

    /**
     * Add the given role.
     * @param roleName the name of the role.
     */
    public void addRoleName(final String roleName) {
        this.roleNameList.add(roleName);
    }
}
