/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: LifeCycleCallback.java 2054 2007-11-20 14:43:55Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.xml.struct.common;

/**
 * This class defines the implementation of an element of callback type (post
 * construct, pre destroy, etc).
 * @author Florent Benoit
 */
public class LifeCycleCallback {

    /**
     * Name of this element.
     */
    public static final String POST_ACTIVATE = "post-activate";

    /**
     * Name of this element.
     */
    public static final String POST_CONSTRUCT = "post-construct";

    /**
     * Name of this element.
     */
    public static final String PRE_DESTROY = "pre-destroy";

    /**
     * Name of this element.
     */
    public static final String PRE_PASSIVATE = "pre-passivate";

    /**
     * Element &lt;lifecycle-callback-class&gt;.
     */
    private String lifecycleCallbackClass = null;

    /**
     * Element &lt;lifecycle-callback-method&gt;.
     */
    private String lifecycleCallbackMethod = null;

    /**
     * Constructor.
     */
    public LifeCycleCallback() {

    }

    /**
     * Sets the name of the class.
     * @param lifecycleCallbackClass the name of the class
     */
    public void setLifecycleCallbackClass(final String lifecycleCallbackClass) {
        this.lifecycleCallbackClass = lifecycleCallbackClass;
    }

    /**
     * @return the class value.
     */
    public String getLifecycleCallbackClass() {
        return lifecycleCallbackClass;
    }

    /**
     * Sets the name of the method.
     * @param lifecycleCallbackMethod the name of the method
     */
    public void setMethodName(final String lifecycleCallbackMethod) {
        this.lifecycleCallbackMethod = lifecycleCallbackMethod;
    }

    /**
     * @return the method name.
     */
    public String getLifecycleCallbackMethod() {
        return lifecycleCallbackMethod;
    }

}
